@@ -33,7 +33,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.3 2006/12/16 19:05:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.4 2006/12/19 13:29:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -41,7 +41,7 @@
 /**
  * С
  */
-define('SYL_VERSION', '0.6.0');
+define('SYL_VERSION', '0.6.1');
 
 /**
  * ١ǥ쥯ȥ
@@ -56,7 +56,7 @@ define('SYL_CONFIG_SYSTEM_ERROR_LOG', true);
 /**
  * PHPƥ२顼¸ե
  */
-define('SYL_CONFIG_SYSTEM_ERROR_LOG_FILE', SYL_DIR . '/resource/syslogs/phperror_' . date('Ymd') . '.log');
+define('SYL_CONFIG_SYSTEM_ERROR_LOG_FILE', SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log');
 
 /**
  * ǥХå٥
