@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.1 2006/12/16 19:09:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.2 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,7 +53,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.1 2006/12/16 19:09:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.2 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorCmd extends SyL_Error
@@ -87,9 +87,11 @@ class SyL_ErrorCmd extends SyL_Error
             // 顼פμ
             $error_type  = $this->getErrorType($error_no);
             // 顼ȥ졼μ
-            $error_trace = $this->getTraceConsole();
+            $error_trace = SYL_ERROR_TRACE ? $this->getTraceConsole() : '';
+            // 顼å
+            $error_string = SYL_ERROR ? "[{$error_type}] {$error_message}" : SYL_ERROR_MESSAGE;
             // 顼ɽ
-            $this->displayErrorDefault($error_type, $error_message, $error_trace);
+            $this->displayErrorDefault($error_string, $error_trace);
             // 
             $this->logging($error_no, $error_message);
 
@@ -104,14 +106,13 @@ class SyL_ErrorCmd extends SyL_Error
      * ǥեȥ顼
      *
      * @access private
-     * @param string 顼
      * @param string 顼å
      * @param string 顼ȥ졼
      */
-    function displayErrorDefault($error_type, $error_message, $error_trace)
+    function displayErrorDefault($error_string, $error_trace)
     {
-        echo "[" . $error_type . "] " . $error_message;
-        if (SYL_ERROR_TRACE) {
+        echo $error_string;
+        if ($error_trace) {
             echo $this->eof;
             echo $error_trace;
         }
@@ -128,7 +129,7 @@ class SyL_ErrorCmd extends SyL_Error
         $error_trace = $this->getTrace();
         $i = count($error_trace);
         $error_trace_result = '';
-        if (SYL_ERROR_TRACE && ($i > 0)) {
+        if ($i > 0) {
             // 顼ȥ졼ɽκ
             $error_trace_result .= "------ start Debug Trace ------" . $this->eof;
             foreach ($error_trace as $value) {
