@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.5 2006/12/16 19:09:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,7 +53,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.5 2006/12/16 19:09:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -87,7 +87,7 @@ class SyL_ErrorWeb extends SyL_Error
             // 顼פμ
             $error_type  = $this->getErrorType($error_no);
             // 顼ȥ졼μ
-            $error_trace = $this->getTraceHtml();
+            $error_trace = SYL_ERROR_TRACE ? $this->getTraceHtml() : '';
 
             // 顼ɽȽ
             $error_View_type = '';
@@ -99,7 +99,9 @@ class SyL_ErrorWeb extends SyL_Error
 
             // 顼ɽ
             $func_name = "displayError{$error_View_type}";
-            call_user_func(array(&$this, $func_name), $error_type, $error_message, $error_trace);
+            // 顼å
+            $error_string = SYL_ERROR ? "[{$error_type}] {$error_message}" : SYL_ERROR_MESSAGE;
+            call_user_func(array(&$this, $func_name), $error_string, $error_trace);
             // 
             $this->logging($error_no, $error_message);
 
@@ -114,14 +116,13 @@ class SyL_ErrorWeb extends SyL_Error
      * ǥեȥ顼
      *
      * @access private
-     * @param string 顼
      * @param string 顼å
      * @param string 顼ȥ졼
      */
-    function displayErrorDefault($error_type, $error_message, $error_trace)
+    function displayErrorDefault($error_string, $error_trace)
     {
-        echo "[{$error_type}] {$error_message}";
-        if (SYL_ERROR_TRACE) {
+        echo $error_string;
+        if ($error_trace) {
             echo "<br><br>";
             echo $error_trace;
         }
@@ -131,14 +132,11 @@ class SyL_ErrorWeb extends SyL_Error
      * ƥץ졼ȥ顼
      *
      * @access private
-     * @param string 顼
      * @param string 顼å
      * @param string 顼ȥ졼
      */
-    function displayErrorTemplate($error_type, $error_message, $error_trace)
+    function displayErrorTemplate($error_string, $error_trace)
     {
-        // 顼å
-        $error_string = "[{$error_type}] {$error_message}";
         if (is_file(SYL_WEBAPP_LIB_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
             // 顼ƥץ졼ɤ߹
             // $error_string
@@ -153,11 +151,10 @@ class SyL_ErrorWeb extends SyL_Error
      * 顼ڡ˥쥯
      *
      * @access private
-     * @param string 顼
      * @param string 顼å
      * @param string 顼ȥ졼
      */
-    function displayErrorRedirect($error_type, $error_message, $error_trace)
+    function displayErrorRedirect($error_message, $error_trace)
     {
         header('Location: ' . SYL_ERROR_FORWARD_FILE);
     }
@@ -173,7 +170,7 @@ class SyL_ErrorWeb extends SyL_Error
         $error_trace = $this->getTrace();
         $i = count($error_trace);
         $error_trace_result = '';
-        if (SYL_ERROR_TRACE && ($i > 0)) {
+        if ($i > 0) {
             // 顼ȥ졼ɽκ
             $error_trace_result .= '<table border="1" cellspacing="0" cellpadding="3" bgcolor="#FFFFFF">' . "\r\n";
             $error_trace_result .= '<tr>' . "\r\n";
