@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.5 2006/12/16 19:10:08 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_FileWriter.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.5 2006/12/16 19:10:08 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerFile extends SyL_Logger
@@ -99,7 +99,7 @@ class SyL_LoggerFile extends SyL_Logger
             $message = sprintf ('%s [%s] %s "%s %s" %s', date('Y-m-d H:i:s'), $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
         }
         if ($this->immediate || ($level == '')) {
-            $this->writer->write( $message . $this->eof );
+            $this->writer->write($message . $this->eof);
         } else {
             $this->buffer[] = $message;
         }
@@ -118,17 +118,6 @@ class SyL_LoggerFile extends SyL_Logger
             $this->writer = null;
         }
     }
-
-    /**
-     * 
-     * register_shutdown_functionǥ뤵
-     *
-     * @access public
-     */
-    function closeFinal()
-    {
-        $this->close();
-    }
 }
 
 ?>
