@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestSession.php,v 1.5 2006/12/16 19:10:17 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestSession.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,11 +44,19 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestSession.php,v 1.5 2006/12/16 19:10:17 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestSession.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestSession extends SyL_Request
 {
+    /**
+     * DBå󥪥֥
+     *
+     * @access private
+     * @var object
+     */
+    var $session_db = null;
+
     /**
      * 󥹥ȥ饯
      *
@@ -73,7 +81,15 @@ class SyL_RequestSession extends SyL_Request
 
             // PHP 4.3.3 ʹ
             //session_regenerate_id();
-            session_start();
+
+            if (strtolower(SYL_SESSION_TYPE) == 'db') {
+                // DBå
+                include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestSessionDB.php';
+                $this->session_db =& new SyL_RequestSessionDB();
+            } else {
+                // ǥեȥå
+                session_start();
+            }
 
             $this->parameters =& $_SESSION;
         }
