@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loggers.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -241,9 +241,17 @@ class SyL_Error
 
             // 顼٥˥¸
             switch ($error_no) {
-            case SYL_LOG_WARN: SyL_Loggers::warn($log_string);  break; // E_WARNING
-            case SYL_LOG_INFO: SyL_Loggers::info($log_string);  break; // E_NOTICE
-            default:           SyL_Loggers::error($log_string); break; // 嵭ʳ
+            case E_WARNING:
+            case E_USER_WARNING:
+                SyL_Loggers::warn($log_string);
+                break;
+            case E_NOTICE:
+            case E_USER_NOTICE:
+                SyL_Loggers::notice($log_string);
+                break;
+            default:
+                SyL_Loggers::error($log_string);
+                break;
             }
         }
     }
