@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LocationManager.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LocationManager.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LocationManager.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LocationManager.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LocationManager
@@ -150,6 +150,9 @@ class SyL_LocationManager
         $this->template_dir = $controller->getTemplateDir();
         // ȥ򥻥å
         $this->controller =& $controller;
+
+        // ǥХå - ξ
+        SyL_Loggers::debug("[LocationManager] action info  name: {$this->action_name} dir: {$this->action_dir} file: {$this->action_file} class: {$this->action_class}");
     }
 
     /**
@@ -253,6 +256,10 @@ class SyL_LocationManager
         $template_file = $this->convertPath($this->template_file, false);
         $real_path     = realpath($template_dir . $template_file);
         $reg           = '/^' . preg_quote($template_dir, '/') . '/';
+
+        // ǥХå - ƥץ졼Ȥξ
+        SyL_Loggers::debug("[LocationManager] template info  dir: {$template_dir} file: {$template_file}");
+
         // ե¸ߥå
         if (!$real_path || !preg_match($reg, $real_path)) {
             SyL_Router::redirect404();
@@ -321,22 +328,6 @@ class SyL_LocationManager
     function &getValues()
     {
         $values = array();
-        // ꥯȥѥ᡼
-        if (SYL_TEMPLATE_REQUEST_DATA) {
-            $obj    =& $this->requests->getParameterObject();
-            $values += $obj->getParameterAll();
-        }
-        // åͤ
-        if (SYL_TEMPLATE_SESSION_DATA) {
-            $obj    =& $this->requests->getSessionObject();
-            $values += $obj->getParameterAll();
-        }
-        // åͤ
-        if (SYL_TEMPLATE_COOKIE_DATA) {
-            $obj    =& $this->requests->getCookieObject();
-            $values += $obj->getParameterAll();
-        }
-
         // ѥ᡼
         if ($this->isAction()) {
             // 󥪥֥Ȥ¸ߤʥ¹ԸˤʤС
