@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Logger
@@ -166,15 +166,6 @@ class SyL_Logger
         $this->logAll();
     }
 
-    /**
-     * 
-     * register_shutdown_functionǥ뤵
-     *
-     * @access public
-     */
-    function closeFinal()
-    {
-    }
 }
 
 ?>
