@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loggers.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loggers.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_Logger.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loggers.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loggers.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Loggers
@@ -195,17 +195,17 @@ class SyL_Loggers
         }
     }
 
-  /**
-   * 
-   *
-   * @access public
-   */
-  function closeFinal()
-  {
-    foreach (array_keys($this->loggers) as $key) {
-      $this->loggers[$key]->closeFinal();
+    /**
+     * 
+     *
+     * @access public
+     */
+    function close()
+    {
+        foreach (array_keys($this->loggers) as $key) {
+            $this->loggers[$key]->close();
+        }
     }
-  }
 }
 
 ?>
