@@ -6,7 +6,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: project.php,v 1.1 2006/12/16 19:06:16 seasonstream Exp $
+ * @version   CVS: $Id: project.php,v 1.2 2006/12/19 13:29:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Project
@@ -32,8 +32,8 @@ class Project
         $project_dir     = $cmd->getArg('-d');
         $app_name        = $cmd->getArg('-w');
         $controller_file = $cmd->getArg('-c');
-        $action_files    = $cmd->getArg('-a');
-        $template_files  = $cmd->getArg('-t');
+        //$action_files    = $cmd->getArg('-a');
+        //$template_files  = $cmd->getArg('-t');
 
         // -------------------------------------------------
         // ץȥǥ쥯ȥå
@@ -115,6 +115,8 @@ class Project
         // -------------------------------------------------
         // եå
         // -------------------------------------------------
+        $action_files = array('index');
+/*
         $action_dir = $project_dir . 'app/' . $app_name . '/actions/';
         $cnt = count($action_files);
         if ($cnt == 0) {
@@ -140,10 +142,13 @@ class Project
                 }
             }
         }
+*/
 
         // -------------------------------------------------
         // ƥץ졼ȥեå
         // -------------------------------------------------
+        $template_files = array('index');
+/*
         $template_dir = $project_dir . 'app/' . $app_name . '/templates/';
         $cnt = count($template_files);
         if ($cnt == 0) {
@@ -169,7 +174,7 @@ class Project
                 }
             }
         }
-
+*/
         // -------------------------------------------------
         // ץȺ
         // -------------------------------------------------
